@@ -1,8 +1,9 @@
 'use strict';
 
 
-exports.handler = (event, context, callback) => {
+exports.handler = async (event, context, callback) => {
+
 	console.log("Function loaded! " + context.functionName  +  ":"  +  context.functionVersion);
 
 	callback(null, "Success");
-}
\ No newline at end of file
+}
