@@ -15,16 +15,6 @@ class TestApiGatewayV2Authorizer(TestCase):
         )
         self.assertEquals(auth.auth_type, "oauth2")
 
-    def test_create_oidc_auth(self):
-        auth = ApiGatewayV2Authorizer(
-            api_logical_id="logicalId",
-            name="authName",
-            open_id_connect_url="https://example.com",
-            jwt_configuration={"config": "value"},
-            id_source="https://example.com",
-        )
-        self.assertEquals(auth.auth_type, "openIdConnect")
-
     def test_create_authorizer_no_id_source(self):
         with pytest.raises(InvalidResourceException):
             auth = ApiGatewayV2Authorizer(
