@@ -995,7 +995,7 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
             ]
         }
 
-        self.editor.add_resource_policy(resourcePolicy, "/foo", "123", "prod")
+        self.editor.add_custom_statements(resourcePolicy.get("CustomStatements"))
 
         expected = {
             "Version": "2012-10-17",
@@ -1007,6 +1007,33 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
 
         self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
 
+    def test_must_add_fn_if_custom_statements(self):
+
+        resourcePolicy = {
+            "CustomStatements": {
+                "Fn::If": [
+                    "condition",
+                    {"Action": "execute-api:Invoke", "Resource": ["execute-api:/*/*/*"]},
+                    {"Action": "execute-api:blah", "Resource": ["execute-api:/*/*/*"]},
+                ]
+            }
+        }
+
+        self.editor.add_custom_statements(resourcePolicy.get("CustomStatements"))
+
+        expected = {
+            "Version": "2012-10-17",
+            "Statement": {
+                "Fn::If": [
+                    "condition",
+                    {"Action": "execute-api:Invoke", "Resource": ["execute-api:/*/*/*"]},
+                    {"Action": "execute-api:blah", "Resource": ["execute-api:/*/*/*"]},
+                ]
+            },
+        }
+
+        self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
+
     def test_must_add_iam_allow(self):
         ## fails
         resourcePolicy = {"AwsAccountWhitelist": ["123456"]}
@@ -1140,17 +1167,7 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                         {"Fn::Sub": ["execute-api:/${__Stage__}/GET/foo", {"__Stage__": "prod"}]},
                     ],
                     "Effect": "Deny",
-                    "Condition": {"StringNotEquals": {"aws:SourceVpc": "vpc-123"}},
-                    "Principal": "*",
-                },
-                {
-                    "Action": "execute-api:Invoke",
-                    "Resource": [
-                        {"Fn::Sub": ["execute-api:/${__Stage__}/PUT/foo", {"__Stage__": "prod"}]},
-                        {"Fn::Sub": ["execute-api:/${__Stage__}/GET/foo", {"__Stage__": "prod"}]},
-                    ],
-                    "Effect": "Deny",
-                    "Condition": {"StringNotEquals": {"aws:SourceVpce": "vpce-345"}},
+                    "Condition": {"StringNotEquals": {"aws:SourceVpc": ["vpc-123"], "aws:SourceVpce": ["vpce-345"]}},
                     "Principal": "*",
                 },
             ],
@@ -1183,7 +1200,7 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                         {"Fn::Sub": ["execute-api:/${__Stage__}/GET/foo", {"__Stage__": "prod"}]},
                     ],
                     "Effect": "Deny",
-                    "Condition": {"StringEquals": {"aws:SourceVpc": "vpc-123"}},
+                    "Condition": {"StringEquals": {"aws:SourceVpc": ["vpc-123"]}},
                     "Principal": "*",
                 },
             ],
@@ -1201,6 +1218,7 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
         }
 
         self.editor.add_resource_policy(resourcePolicy, "/foo", "123", "prod")
+        self.editor.add_custom_statements(resourcePolicy.get("CustomStatements"))
 
         expected = {
             "Version": "2012-10-17",
