@@ -1,7 +1,7 @@
 from parameterized import parameterized
 from unittest import TestCase
 
-from samtranslator.model.intrinsics import is_instrinsic, make_shorthand
+from samtranslator.model.intrinsics import is_intrinsic, make_shorthand
 
 
 class TestIntrinsics(TestCase):
@@ -10,16 +10,16 @@ class TestIntrinsics(TestCase):
 
         input = {intrinsic_name: ["some value"]}
 
-        self.assertTrue(is_instrinsic(input))
+        self.assertTrue(is_intrinsic(input))
 
     def test_is_intrinsic_on_empty_input(self):
-        self.assertFalse(is_instrinsic(None))
+        self.assertFalse(is_intrinsic(None))
 
     def test_is_intrinsic_on_non_dict_input(self):
-        self.assertFalse(is_instrinsic([1, 2, 3]))
+        self.assertFalse(is_intrinsic([1, 2, 3]))
 
     def test_is_intrinsic_on_intrinsic_like_dict_input(self):
-        self.assertFalse(is_instrinsic({"Ref": "foo", "key": "bar"}))
+        self.assertFalse(is_intrinsic({"Ref": "foo", "key": "bar"}))
 
     @parameterized.expand([({"Ref": "foo"}, "${foo}"), ({"Fn::GetAtt": ["foo", "Arn"]}, "${foo.Arn}")])
     def test_make_shorthand_success(self, input, expected):
